pub enum Error {
DecodingError(Error),
AwarenessEncoding(Error),
PermissionDenied {
reason: String,
},
Unsupported(u8),
IO(Error),
Other(Box<dyn Error + Send + Sync>),
}Expand description
An error type returned in response from y-sync Protocol.
Variants
DecodingError(Error)
Incoming Y-protocol message couldn’t be deserialized.
AwarenessEncoding(Error)
Applying incoming Y-protocol awareness update has failed.
PermissionDenied
An incoming Y-protocol authorization request has been denied.
Unsupported(u8)
Thrown whenever an unknown message tag has been sent.
IO(Error)
Thrown in case of I/O errors.
Other(Box<dyn Error + Send + Sync>)
Custom dynamic kind of error, usually related to a warp internal error messages.